<?php
/**
 * @name nodeNotes.lib.php
 * @description Librairie avec des fonctions utilisée pour les notes de noeud
 * @author Quentin George <q.george@esia-sa.com>
 * @date 18/02/2025
 */

namespace NodeNotes;
{
    /**
	 * Ajoute une note de noeud lors d'une action sur un service (aquittement, assignement, ...)
	 * @param array $lang référence variable de langue
	 * @param array $user référence variable user.class
	 * @param PDO $dbconnection
	 * @param integer $nodeId identifiant du noeud sur lequel on ajouter les notes
	 * @param string $type type d'action (acquitte, cancel_acquit, assign, cancelAssign)
	 * @param integer|array $happenErrors identifiant de l'erreur ou array d'id d'erreurs sur laquelle l'action a été faite
	 * @throws EsiaDbException | Exception
	 * @retval array|string liste d'erreur survenues par $happenErrors ou vide si pas d'erreur
	 */
    function setErrorHappenNote(&$lang, &$user, $dbconnection, $nodeId, $type, $happenErrors)
    {
		$addSysNoteErrors = array();

		if(empty($nodeId) || !is_numeric($nodeId))
		{
			throw new \Exception('Node ID is missing.');
		}
        if(empty($type))
		{
			throw new \Exception('Missing system note type.');
		}
		if(empty($happenErrors))
		{
			throw new \Exception('Missing happen errors ID.');
		}

		// We require langSite to set automatic notes (acquit, assign, ...) in the site language instead of in the user lang
		if(LANG != $user->getLang())
		{
			// Get node note lang var for web interface default language from esia.conf to set automatic messages ($langSite)
			$langVarName = 'langSite';
			$siteLangPath = $_SERVER['DOCUMENT_ROOT'] . '/lang/' . LANG . '/';
			if(file_exists($siteLangPath . LANG . '.php'))
			{
				include $siteLangPath . LANG . '.php';
			}
			if(file_exists($siteLangPath . '/common_plugin_name.php'))
			{
				include $siteLangPath . '/common_plugin_name.php';
			}
		}
		else
		{
			// User has the same lang than the site
			$langSite = &$lang;
		}

		$nodeErrors = \Model_esia::getNodeErrorByHappenId($dbconnection, $nodeId, $happenErrors);
		foreach($nodeErrors as $nodeErr)
		{
			try
			{
				$commonName = \Model_esia::getCommonName($langSite, $nodeErr['service'], $nodeErr['plugin_name']);
				$langKey = 'LGD_' . strtoupper($nodeErr['type']);
				if(isset($langSite[$langKey]))
				{
					$errState = $langSite[$langKey];
				}
				else
				{
					$errState = $langSite['LGD_UNKNOWN'];
				}

				// Set message for this action type
				if($type == 'acquitte')
				{
					$threadType = 'ACQUIT';

					$message = $commonName . " =>&nbsp;" . $errState . "\n\n";
					$message .= $nodeErr['message'] . "\n\n";
					$message .= $langSite['NODE_NOTE_ERROR_START'] . $nodeErr['time'] . "\n";
				}
				elseif($type == 'cancel_acquit')
				{
					$threadType = 'UNACQUIT';

					$message = $commonName . " =>&nbsp;" . $errState . "\n\n";
					$message .= $nodeErr['message'] . "\n";
				}
				elseif($type == 'assign')
				{
					$threadType = 'ASSIGNED';

					$message = $user->getName() . $langSite['NODE_NOTE_ERROR_SELF_ASSIGN'] . "\n";
					$message .= $commonName . " =>&nbsp;" . $errState . "\n\n";
					$message .= $langSite['NODE_NOTE_ERROR_START'] . $nodeErr['time'] . "\n";
				}
				elseif($type == 'cancelAssign')
				{
					$threadType = 'UNASSIGNED';

					$message = $user->getName() . $langSite['NODE_NOTE_ERROR_ASSIGN_SUPPORT'] . "\n";
					$message .= $commonName . " =>&nbsp;" . $errState . "\n\n";
					$message .= $langSite['NODE_NOTE_ERROR_START'] . $nodeErr['time'] . "\n";
				}
				else
				{
					throw new \Exception('Wrong action type (' . $type . ').');
				}

				\Model_esia::addDeviceSystemNote($dbconnection, $langSite, $user->getId(), $user->getName(), $nodeId, $threadType, $message, $nodeErr['happen_id']);
			}
			catch(\EsiaDbException | \Exception $e)
			{
				$addSysNoteErrors[] = 'Error adding ' . $type . ' note for ' . $nodeErr['plugin_name'] . ' : ' . $e->getMessage();
			}
		}

        return $addSysNoteErrors;
    }
}

?>
